{
  pkgs,
  inputs,
  ...
}:
let
  common = import ../common.nix;
  username = common.username;
  dir = common.dir;
in
{
  imports = [
    inputs.catppuccin.homeManagerModules.catppuccin
    inputs.nixvim.homeManagerModules.nixvim
    ./cava.nix
    ./default-applications.nix
    ./development
    ./fish.nix
    ./gtk.nix
    ./mpv.nix
    ./nextcloud.nix
    ./rofi
    ./wlogout
    ./hyprland
    ./spicetify.nix
    ./yazi
  ];

  home = {
    username = username;
    homeDirectory = dir.home;

    sessionVariables = {
      XDG_PICTURES_DIR = dir.pictures; # Define the default dir for pictures
    };

    # You can update Home Manager without changing this value. See
    # the Home Manager release notes for a list of state version
    # changes in each release.
    stateVersion = common.system.version;
  };

  programs = {
    btop.enable = true;

    # Let Home Manager install and manage itself.
    home-manager.enable = true;

    kitty = {
      enable = common.terminal == "kitty";
      settings.window_padding_width = 10;
    };
  };

  services = {
    gpg-agent = {
      enable = true;
      pinentryPackage = pkgs.pinentry-curses;
    };
  };
}
